==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/lv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ielādē priekšskatījumu...",
    "Saved" : "Saglabāts",
    "Admin" : "Admin",
    "a safe home for all your data" : "droša vieta visiem jūsu datiem",
    "The given name is too long" : "Norādītais nosaukums ir pārāk garš",
    "The given web address is too long" : "Norādītā adrese ir pārāk gara",
    "The given slogan is too long" : "Norādītais teiciens ir pārāk garšs",
    "The given color is invalid" : "Norādītā krāsa ir nederīga",
    "No file uploaded" : "Nav augšupielādēta faila",
    "Unsupported image type" : "Neatbalstīts attēla tips",
    "You are already using a custom theme" : "Tu jau izmanto pielāgotu tēmu",
    "Theming" : "Dizains",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Tēmošana padara iespējamu viegli pielāgot savas instances un atbalstošo klientaplikāciju izskatu un sajūtu. Tas būs redzams visiem lietotājiem.",
    "Name" : "Nosaukums",
    "Reset to default" : "Atiestatīt",
    "Web address" : "Tīmekļa adrese",
    "Web address https://…" : "Servera adrese https://…",
    "Slogan" : "Sauklis",
    "Color" : "Krāsa",
    "Logo" : "Logo",
    "Upload new logo" : "Augšupielādēt jaunu logo",
    "Login image" : "Pieslēgšanās fona attēls",
    "Upload new login background" : "Augšupielādēt jaunu pieslēgšanās fona attēlu",
    "Remove background image" : "Noņemt fona attēlu",
    "reset to default" : "Atiestatīt",
    "Log in image" : "Pieslēgšanas fona attēls"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/lv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Ielādē priekšskatījumu...",
    "Saved" : "Saglabāts",
    "Admin" : "Admin",
    "a safe home for all your data" : "droša vieta visiem jūsu datiem",
    "The given name is too long" : "Norādītais nosaukums ir pārāk garš",
    "The given web address is too long" : "Norādītā adrese ir pārāk gara",
    "The given slogan is too long" : "Norādītais teiciens ir pārāk garšs",
    "The given color is invalid" : "Norādītā krāsa ir nederīga",
    "No file uploaded" : "Nav augšupielādēta datne",
    "Unsupported image type" : "Neatbalstīts attēla tips",
    "Theming" : "Dizains",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Tēmošana padara iespējamu viegli pielāgot savas instances un atbalstošo klientaplikāciju izskatu un sajūtu. Tas būs redzams visiem lietotājiem.",
    "Name" : "Nosaukums",
    "Reset to default" : "Atiestatīt",
    "Web address" : "Tīmekļa adrese",
    "Web address https://…" : "Servera adrese https://…",
    "Slogan" : "Sauklis",
    "Color" : "Krāsa",
    "Logo" : "Logo",
    "Upload new logo" : "Augšupielādēt jaunu logo",
    "Login image" : "Pieslēgšanās fona attēls",
    "Upload new login background" : "Augšupielādēt jaunu pieslēgšanās fona attēlu",
    "Remove background image" : "Noņemt fona attēlu",
    "You are already using a custom theme" : "Tu jau izmanto pielāgotu tēmu",
    "reset to default" : "Atiestatīt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
